@@ -115,15 +115,18 @@ csvFile <- function(input, output, session, nfactor.limit = 20) {
   data <- eventReactive(input$file, {
     validate(need((grepl("csv", userFile()$name) == T) | (grepl("xlsx", userFile()$name) == T) | (grepl("sav", userFile()$name) == T) | (grepl("sas7bdat", userFile()$name) == T), message = "Please upload csv/xlsx/sav/sas7bdat file"))
     if (grepl("csv", userFile()$name) == T){
-      out = data.table::fread(userFile()$datapath, check.names = F, integer64 = "double")
+      out <- data.table::fread(userFile()$datapath, check.names = F, integer64 = "double")
     } else if (grepl("xlsx", userFile()$name) == T){
       out = data.table::data.table(readxl::read_excel(userFile()$datapath), check.names = F, integer64 = "double")
     } else if (grepl("sav", userFile()$name) == T){
-      out = data.table::data.table(haven::read_sav(userFile()$datapath), check.names = F, integer64 = "double")
+      out <- data.table::data.table(tryCatch(haven::read_sav(userFile()$datapath), error = function(e){return(haven::read_sav(userFile()$datapath, encoding = "latin1"))}), check.names = F)
+      #out = data.table::data.table(haven::read_sav(userFile()$datapath, encoding = "latin1"), check.names = F, integer64 = "double")
     } else if (grepl("sas7bdat", userFile()$name) == T){
-      out = data.table::data.table(haven::read_sas(userFile()$datapath), check.names = F, integer64 = "double")
+      out <- data.table::data.table(tryCatch(haven::read_sas(userFile()$datapath), error = function(e){return(haven::read_sas(userFile()$datapath, encoding = "latin1"))}), check.names = F)
+      #out = data.table::data.table(haven::read_sas(userFile()$datapath), check.names = F, integer64 = "double")
     } else if (grepl("dta", userFile()$name) == T){
-      out = data.table::data.table(haven::read_dta(userFile()$datapath), check.names = F, integer64 = "double")
+      out <- data.table::data.table(tryCatch(haven::read_dta(userFile()$datapath), error = function(e){return(haven::read_dta(userFile()$datapath, encoding = "latin1"))}), check.names = F)
+      #out = data.table::data.table(haven::read_dta(userFile()$datapath), check.names = F, integer64 = "double")
     } else {
       stop("Not supported format.")
     }
